import React, {useCallback, useState, useEffect} from "react";
import {connect, useDispatch} from "react-redux";
import {Container, FormControl, InputGroup} from "react-bootstrap";
import compair1 from "../../image/comair2.png";
import searchCm from "../../image/searchCm.png";
import CompairProductDetailTable from "./compairProductDetailTable";
import SliderDataAccess from "dataAccess/sliderDataAccess";
import ReactHtmlParser from "react-html-parser";
import ProductDataAccess from "dataAccess/productDataAccess";
import Rating from "react-rating";
import Router from "router";
import {Link, useHistory} from "react-router-dom";
import {actions as cartActions} from "@redux/cartRedux";
import {actions as favoriteActions} from "@redux/favoriteRedux";
import {isUserLoggedIn} from "services/userServices";
import cartServices from "../../services/cartServices";
import favoriteServices from "../../services/favouriteServices";

const ProductCompair = (props: any) => {
    const dispatch = useDispatch();
    const productSlag = props.match.params.compairSlag;
    let history = useHistory();
    const [currency, setCurrency] = useState(null);
    useEffect(() => {
        SliderDataAccess.getSettingData()
            .then((data) => {
                setCurrency(data.currency_symbol);
            })
            .catch((error) => {
            });
    }, []);

    const [searchText, setSearchText] = useState("");
    const [productName, setProductName] = useState(null);
    const [productImg, setProductImg] = useState(null);
    const [productPrice, setProductPrice] = useState(null);
    const [productId, setProductId] = useState(null);
    const [productQuantity, setProductQuantity] = useState(null);
    const [rating, setRating] = useState(null);
    const [category, setCategory] = useState(null);
    const [allCategory, setAllCategory] = useState([]);
    const [description, setDescription] = useState(null);

    const [comapirProductName, setCompairProductName] = useState(null);
    const [comapirProductImg, setCompairProductImg] = useState(null);
    const [comapirProductId, setCompairProductId] = useState(null);
    const [comapirProductPrice, setCompairProductPrice] = useState(null);
    const [comapirProductQuantity, setCompairProductQuantity] = useState(null);
    const [comapirProductrating, setCompairProductRating] = useState(null);
    const [comapirProductCategory, setCompairProductCategory] = useState(null);
    const [compairDetail, setCompairDetail] = useState(null);
    const [slug, setSlug] = useState(false);

    const handleCategory = (slug) => {
        if (slug) {
            setSlug(true);
        }

        ProductDataAccess.getProductDetails(slug)
            .then((data) => {
                setCompairDetail(data.data.product.description);
                setCompairProductName(data.data.product.name);
                setCompairProductId(data.data.product.id);
                setCompairProductImg(data.data.product.image1);
                setCompairProductPrice(data.data.product.price);
                setCompairProductQuantity(data.data.product.quantity);
                setCompairProductRating(data.data.product.rating.avg_rating);
                setCompairProductCategory(data.data.product.product_category.name);
            })
            .catch((error) => {
            });
    };

    useEffect(() => {
        SliderDataAccess.getCompairData(productSlag).then((data) => {
            setDescription(data.data.products.description);
            setProductName(data.data.products.name);
            setProductImg(data.data.products.image1);
            setProductPrice(data.data.products.price);
            setProductId(data.data.products.id);
            setProductQuantity(data.data.products.quantity);
            setRating(data.data.products.rating.avg_rating);
            setCategory(data.data.products.product_category.name);
            setAllCategory(data.data.comparable_products);

            // setImages(data.data);
        });
    }, []);

    const search = useCallback(() => {
        if (searchText.length > 0) props.history.push("/search/" + searchText);
    }, [props.history, searchText]);

    return (
        <div className="container">
            <div className="row mt-5">
                <div className="col-12">
                    <button
                        type="button"
                        className="btn btn-link"
                        onClick={() => history.goBack()}
                    >
                        <i className="fa fa-arrow-left"></i> Go Back
                    </button>
                </div>
                <div className="col-lg-6 col-md-6">
                    <h3 className="category-top-title">Compare Products</h3>
                </div>
                <div
                    className="col-lg-6 col-md-6"
                    style={{
                        display: "flex",
                        alignContent: "center",
                        justifyContent: "center",
                        flexDirection: "column",
                    }}
                >
                    <div className="form-group">
                        <label htmlFor="comp-select">Select Another Product</label>
                        <select
                            className="form-control select2"
                            id="comp-select"
                            style={{width: "100%"}}
                            onChange={(e) => handleCategory(e.target.value)}
                        >
                            <option selected>Compare...</option>
                            {allCategory.map((category, index) => (
                                <option value={category.slug} key={index}>
                                    {category.name}
                                </option>
                            ))}
                        </select>
                    </div>
                </div>
            </div>
            <div className="row d-flex justify-content-center">
                <div className="col-xl-6 col-lg-6 col-md-6 col-12 col-sm-12 col-xs-12 col-12 ">
                    <div className="pl-1">
                        <div className="compair-product-detail">
                            <div
                                className="image-container"
                                style={{
                                    height: "52vh",
                                    background: "white",
                                    padding: "35px",
                                    display: 'flex',
                                    justifyContent: 'center'
                                }}
                            >
                                <img
                                    src={productImg}
                                    className="compairImg"
                                    alt="compair"
                                    style={{maxWidth: "100%"}}
                                />
                            </div>
                            <div className="mt-3">
                                <h4 className="product-Name" style={{
                                    height: "109px",
                                    overflow: "hidden",
                                    textOverflow: "ellipsis"
                                }}>{productName}</h4>
                                <h3 className="price mt-4 font-weight-bold">
                                    {currency} {productPrice}
                                </h3>
                            </div>
                        </div>
                        <div>
                            <div className="table-responsive mr-5">
                                <table className="table table-striped">
                                    <tbody>
                                    <tr>
                                        <th scope="row">Category</th>
                                        <td>{category}</td>
                                    </tr>
                                    <tr>
                                        <th scope="row">Quantity</th>
                                        <td>{productQuantity}</td>
                                    </tr>
                                    <tr>
                                        <th scope="row">Rating</th>
                                        <td>
                                            <div
                                                className="rating-content"
                                                style={{color: "gold"}}
                                            >
                                                {rating !== 0 && (
                                                    <span style={{marginRight: "5px"}}>
                              <Rating
                                  fullSymbol="fa fa-star"
                                  emptySymbol="fa fa-star-o"
                                  readonly
                                  initialRating={rating}
                              />
                            </span>
                                                )}
                                                <span style={{color: "gold"}}>
                            {rating === 0 && (
                                <div className="d-flex">
                                    <i className="far fa-star mr-1"></i>
                                    <i className="far fa-star mr-1"></i>
                                    <i className="far fa-star mr-1"></i>
                                    <i className="far fa-star mr-1"></i>
                                    <i className="far fa-star mr-1"></i>
                                </div>
                            )}
                          </span>
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row">Description</th>
                                        <td>
                                            {description === null ? (
                                                <p> No Description </p>
                                            ) : (
                                                <div style={{
                                                    maxHeight: "260px",
                                                    overflow: "hidden",
                                                    textOverflow: "ellipsis"
                                                }}> {ReactHtmlParser(description)} </div>
                                            )}
                                        </td>
                                    </tr>
                                    </tbody>
                                </table>
                                <div style={{
                                    display: "flex",
                                    justifyContent: "center",
                                }}>
                                    {cartServices.isProductOnCart(
                                        productId,
                                        props.cart
                                    ) ? (
                                        <p
                                            className="cart-button"
                                            style={{
                                                width: "fit-content",
                                                padding: "0px 2px 3px 2px",
                                                marginRight: "14px",
                                            }}
                                            onClick={() => {
                                                dispatch(
                                                    cartActions.removeFromCart(
                                                        productId,
                                                        isUserLoggedIn(props.user.user)
                                                    )
                                                );
                                            }}
                                        >
                      <span
                          className="before-click"
                          style={{padding: "10px"}}
                      >
                        <span className="cart">
                          <img
                              className="cart-image"
                              src={
                                  process.env.PUBLIC_URL +
                                  "/images/card-red.png"
                              }
                              alt=""
                              style={{width: "12px"}}
                          />
                        </span>
                        <span
                            className="cart responsive-width"
                            style={{fontSize: "11px"}}
                        >
                          Added
                        </span>
                      </span>
                                        </p>
                                    ) : (
                                        <p
                                            className="cart-button"
                                            style={{
                                                width: "fit-content",
                                                padding: "0px 2px 3px 2px",
                                                marginRight: "14px",
                                            }}
                                            onClick={() => {
                                                dispatch(
                                                    cartActions.addProductToCart(
                                                        productId,
                                                        isUserLoggedIn(props.user.user)
                                                    )
                                                );
                                            }}
                                        >
                      <span
                          className="before-click"
                          style={{padding: "10px"}}
                      >
                        <span className="cart">
                          <img
                              className="cart-image"
                              src={
                                  process.env.PUBLIC_URL +
                                  "/images/card-red.png"
                              }
                              alt=""
                              style={{width: "12px"}}
                          />
                        </span>
                        <span
                            className="cart responsive-width"
                            style={{fontSize: "11px"}}
                        >
                          Add to Cart
                        </span>
                      </span>
                                        </p>
                                    )}
                                    {favoriteServices.isProductOnFavorite(
                                        productId,
                                        props.favorite.favorite
                                    ) ? (
                                        <span
                                            onClick={() => {
                                                dispatch(
                                                    favoriteActions.removeProductFromFavorite(
                                                        productId,
                                                        isUserLoggedIn(props.user.user)
                                                    )
                                                );
                                            }}
                                        >
                                      <p
                                          className="cart-button"
                                          style={{
                                              width: "fit-content",
                                              padding: "0px 2px 3px 2px",
                                          }}
                                      >
                      <span
                          className="before-click"
                          style={{padding: "10px"}}
                      >
                        <span className="cart">
                          <img
                              className="cart-image"
                              src={
                                  process.env.PUBLIC_URL + "/images/like.png"
                              }
                              alt=""
                              style={{width: "12px"}}
                          />
                        </span>
                        <span
                            className="cart responsive-width"
                            style={{fontSize: "11px"}}
                        >
                          Added
                        </span>
                      </span>
                    </p>
                          </span>
                                    ) : (
                                        <span
                                            onClick={() => {
                                                dispatch(
                                                    favoriteActions.addProductToFavorite(
                                                        productId,
                                                        isUserLoggedIn(props.user.user)
                                                    )
                                                );
                                            }}
                                        >
                                      <p
                                          className="cart-button"
                                          style={{
                                              width: "fit-content",
                                              padding: "0px 2px 3px 2px",
                                          }}
                                      >
                      <span
                          className="before-click"
                          style={{padding: "10px"}}
                      >
                        <span className="cart">
                          <img
                              className="cart-image"
                              src={
                                  process.env.PUBLIC_URL + "/images/like.png"
                              }
                              alt=""
                              style={{width: "12px"}}
                          />
                        </span>
                        <span
                            className="cart responsive-width"
                            style={{fontSize: "11px"}}
                        >
                          Add to Wishlist
                        </span>
                      </span>
                    </p>
                          </span>
                                    )}
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div className="col-xl-6 col-lg-6 col-md-6 col-12 col-sm-12 col-xs-12 col-12">
                    <div>
                        {slug == true && (
                            <div className="">
                                <div className="compair-product-detail">
                                    <div
                                        className="image-container"
                                        style={{
                                            height: "52vh",
                                            background: "white",
                                            padding: "35px",
                                            display: 'flex',
                                            justifyContent: 'center'
                                        }}
                                    >
                                        <img
                                            src={comapirProductImg || "https://upload.wikimedia.org/wikipedia/commons/a/ad/YouTube_loading_symbol_3_%28transparent%29.gif"}
                                            className="compairImg"
                                            alt="compair"
                                            style={{maxWidth: "100%"}}
                                        />
                                    </div>
                                    <div className="mt-3">
                                        <h4 className="product-Name" style={{
                                            height: "109px",
                                            overflow: "hidden",
                                            textOverflow: "ellipsis"
                                        }}>{comapirProductName}</h4>
                                        <h3 className="price  mt-4 font-weight-bold">
                                            {currency} {comapirProductPrice}
                                        </h3>
                                    </div>
                                </div>
                                <div>
                                    <div className="table-responsive mr-5">
                                        <table className="table table-striped">
                                            <tbody>
                                            <tr>
                                                <th scope="row">Category</th>
                                                <td>{comapirProductCategory}</td>
                                            </tr>
                                            <tr>
                                                <th scope="row">Quantity</th>
                                                <td>{comapirProductQuantity}</td>
                                            </tr>
                                            <tr>
                                                <th scope="row">Rating</th>
                                                <td>
                                                    <div
                                                        className="rating-content"
                                                        style={{color: "gold"}}
                                                    >
                                                        {comapirProductrating !== 0 && (
                                                            <span style={{marginRight: "5px"}}>
                                  <Rating
                                      fullSymbol="fa fa-star"
                                      emptySymbol="fa fa-star-o"
                                      readonly
                                      initialRating={comapirProductrating}
                                  />
                                </span>
                                                        )}
                                                        <span style={{color: "gold"}}>
                                {comapirProductrating === 0 && (
                                    <div className="d-flex">
                                        <i className="far fa-star mr-1"></i>
                                        <i className="far fa-star mr-1"></i>
                                        <i className="far fa-star mr-1"></i>
                                        <i className="far fa-star mr-1"></i>
                                        <i className="far fa-star mr-1"></i>
                                    </div>
                                )}
                              </span>
                                                    </div>
                                                </td>
                                            </tr>
                                            <tr>
                                                <th scope="row">Description</th>
                                                <td>
                                                    {compairDetail == null ? (
                                                        <p>No Description</p>
                                                    ) : (
                                                        <div style={{
                                                            maxHeight: "260px",
                                                            overflow: "hidden",
                                                            textOverflow: "ellipsis"
                                                        }}> {ReactHtmlParser(compairDetail)} </div>
                                                    )}
                                                </td>
                                            </tr>
                                            </tbody>
                                        </table>
                                        <div style={{
                                            display: "flex",
                                            justifyContent: "center",
                                        }}>
                                            {cartServices.isProductOnCart(
                                                comapirProductId,
                                                props.cart
                                            ) ? (
                                                <p
                                                    className="cart-button"
                                                    style={{
                                                        width: "fit-content",
                                                        padding: "0px 2px 3px 2px",
                                                        marginRight: "14px",
                                                    }}
                                                    onClick={() => {
                                                        dispatch(
                                                            cartActions.removeFromCart(
                                                                comapirProductId,
                                                                isUserLoggedIn(props.user.user)
                                                            )
                                                        );
                                                    }}
                                                >
                      <span
                          className="before-click"
                          style={{padding: "10px"}}
                      >
                        <span className="cart">
                          <img
                              className="cart-image"
                              src={
                                  process.env.PUBLIC_URL +
                                  "/images/card-red.png"
                              }
                              alt=""
                              style={{width: "12px"}}
                          />
                        </span>
                        <span
                            className="cart responsive-width"
                            style={{fontSize: "11px"}}
                        >
                          Added
                        </span>
                      </span>
                                                </p>
                                            ) : (
                                                <p
                                                    className="cart-button"
                                                    style={{
                                                        width: "fit-content",
                                                        padding: "0px 2px 3px 2px",
                                                        marginRight: "14px",
                                                    }}
                                                    onClick={() => {
                                                        dispatch(
                                                            cartActions.addProductToCart(
                                                                comapirProductId,
                                                                isUserLoggedIn(props.user.user)
                                                            )
                                                        );
                                                    }}
                                                >
                      <span
                          className="before-click"
                          style={{padding: "10px"}}
                      >
                        <span className="cart">
                          <img
                              className="cart-image"
                              src={
                                  process.env.PUBLIC_URL +
                                  "/images/card-red.png"
                              }
                              alt=""
                              style={{width: "12px"}}
                          />
                        </span>
                        <span
                            className="cart responsive-width"
                            style={{fontSize: "11px"}}
                        >
                          Add to Cart
                        </span>
                      </span>
                                                </p>
                                            )}
                                            {favoriteServices.isProductOnFavorite(
                                                comapirProductId,
                                                props.favorite.favorite
                                            ) ? (
                                                <span
                                                    onClick={() => {
                                                        dispatch(
                                                            favoriteActions.removeProductFromFavorite(
                                                                comapirProductId,
                                                                isUserLoggedIn(props.user.user)
                                                            )
                                                        );
                                                    }}
                                                >
                                      <p
                                          className="cart-button"
                                          style={{
                                              width: "fit-content",
                                              padding: "0px 2px 3px 2px",
                                          }}
                                      >
                      <span
                          className="before-click"
                          style={{padding: "10px"}}
                      >
                        <span className="cart">
                          <img
                              className="cart-image"
                              src={
                                  process.env.PUBLIC_URL + "/images/like.png"
                              }
                              alt=""
                              style={{width: "12px"}}
                          />
                        </span>
                        <span
                            className="cart responsive-width"
                            style={{fontSize: "11px"}}
                        >
                          Added
                        </span>
                      </span>
                    </p>
                          </span>
                                            ) : (
                                                <span
                                                    onClick={() => {
                                                        dispatch(
                                                            favoriteActions.addProductToFavorite(
                                                                comapirProductId,
                                                                isUserLoggedIn(props.user.user)
                                                            )
                                                        );
                                                    }}
                                                >
                                      <p
                                          className="cart-button"
                                          style={{
                                              width: "fit-content",
                                              padding: "0px 2px 3px 2px",
                                          }}
                                      >
                      <span
                          className="before-click"
                          style={{padding: "10px"}}
                      >
                        <span className="cart">
                          <img
                              className="cart-image"
                              src={
                                  process.env.PUBLIC_URL + "/images/like.png"
                              }
                              alt=""
                              style={{width: "12px"}}
                          />
                        </span>
                        <span
                            className="cart responsive-width"
                            style={{fontSize: "11px"}}
                        >
                          Add to Wishlist
                        </span>
                      </span>
                    </p>
                          </span>
                                            )}
                                        </div>
                                    </div>
                                </div>
                            </div>
                        )}
                    </div>
                </div>
            </div>
        </div>
    );
};

const mapStateToProps = ({cart, favorite, user}) => {
    return {cart: cart.cart, favorite, user};
};
export default connect(mapStateToProps)(ProductCompair);
